@@ -7,7 +7,7 @@ arma::vec normalize_weights(const arma::vec& log_inc_wgt);
 arma::vec initialize_alpha(const int& N);
 double get_exponent_sum(double, arma::vec, int, arma::mat, std::string);
 arma::vec metropolis_hastings_rho(double, int, arma::mat, arma::vec, std::string, int);
-double metropolis_hastings_alpha(double, int, arma::mat, arma::vec, const Rcpp::Nullable<arma::vec>, std::string, double, double, double);
+double metropolis_hastings_alpha(double, int, arma::mat, arma::vec, const Rcpp::Nullable<arma::vec>, const Rcpp::Nullable<arma::vec>, std::string, double, double, double);
 arma::vec get_sample_probabilities(arma::vec, double, arma::vec, int, std::string);
 Rcpp::List calculate_forward_probability(arma::uvec, arma::vec, arma::vec, arma::vec, double, int, std::string);
 double calculate_backward_probability(arma::uvec, arma::vec, arma::vec, arma::vec, arma::vec, double, int, std::string);
