@@ -22,9 +22,13 @@ test_that("get_mallows_loglik works", {
           rankings = mydata,
           log = TRUE
         )
-      }),
-    list(-241.809448010519, -231.458744596071, -283.167543856933,
-         -170.030563541214, -223.987863416978, -224.300341956488))
+      }
+    ),
+    list(
+      -241.809448010519, -231.458744596071, -283.167543856933,
+      -170.030563541214, -223.987863416978, -224.300341956488
+    )
+  )
 
   # A single component
   # Gives exactly the same values as the previous, due to the weights
@@ -40,9 +44,13 @@ test_that("get_mallows_loglik works", {
           rankings = mydata,
           log = TRUE
         )
-      }),
-    list(-241.809448010519, -231.458744596071, -283.167543856933,
-         -170.030563541214, -223.987863416978, -224.300341956488))
+      }
+    ),
+    list(
+      -241.809448010519, -231.458744596071, -283.167543856933,
+      -170.030563541214, -223.987863416978, -224.300341956488
+    )
+  )
 
   expect_equal(
     sprintf("%.3e", get_mallows_loglik(
